#include "opener_server.h"
#include "opener_resource.h"
#include "resource_server.h"

/* Support for providing access to files. */

OpenerResource::OpenerResource(Pages *pages)
: FilePaging(pages)
{
}

int OpenerResource::expected_items()
{
    return Opener_expected_items;
}

ipc_server_handler_type OpenerResource::handler()
{
    return (ipc_server_handler_type) handle_Opener;
}



/* Return a pager object for the given path and flags. */

Pager *OpenerResource::open(const char *path, flags_t flags)
{
    fileid_t fileid = get_fileid(path);

    if (fileid == FILEID_INVALID)
        return NULL;

    return get_pager(fileid, get_flags(flags));
}



/* Opener interface methods. */

long OpenerResource::context(l4_cap_idx_t *context)
{
    OpenerContextResource *resource = new OpenerContextResource(this);

    /* Complete the initialisation and start a server in a new thread.
       If the thread does not start, the resource should be finalised. */

    ResourceServer server(resource);
    long err = server.start_thread();

    /* Return the server capability to the caller. */

    if (!err)
        *context = server.config()->server;

    return err;
}

// vim: tabstop=4 expandtab shiftwidth=4
